@@ -7,7 +7,7 @@ library(R6)
 #' and helps determine which performs best.
 #' @docType class
 #' @importFrom R6 R6Class
-#' @references \url{http://healthcare.ai}
+#' @references \url{http://healthcareai-r.readthedocs.io}
 #' @seealso \code{\link{healthcareai}}
 #'
 #' @export
@@ -28,9 +28,20 @@ SupervisedModelDevelopmentParams <- R6Class("SupervisedModelDevelopmentParams",
     debug = FALSE,
     varImp = TRUE,
     printResults = TRUE,
-    cores = 4,
+    cores = 2,
     tune = FALSE,
-    numberOfTrees = 201,
+    trees = 201,
+    xgb_numberOfClasses = NA,
+    xgb_params = list("objective" = "multi:softprob",
+                  "eval_metric" = "mlogloss",
+                  "num_class" = NA,
+                  "max_depth" = 6, 
+                  "eta" = 0.1, 
+                  "silent" = 0, 
+                  "nthread" = 1),
+    xgb_nrounds = 50,
+    xgb_targetNames = NA,
+    modelName = NULL,
 
     #Constructor
     initialize = function() {
