@@ -8,8 +8,6 @@ df <- read.csv(file = csvfile,
                     header = TRUE,
                     na.strings =  c('NULL', 'NA', ""))
 
-df$InTestWindowFLG <- NULL # Since this is dev step
-
 set.seed(43)
 p <- SupervisedModelDevelopmentParams$new()
 p$df = df
@@ -18,14 +16,14 @@ p$impute = TRUE
 p$debug = FALSE
 p$cores = 1
 p$tune = FALSE
-p$numberOfTrees = 201
+p$trees = 201
 
 ###########
 # Common settings
 
-test_that("Error is thrown when type != regression or classification", {
+test_that("Error is thrown when type != regression or classification or multiclass", {
   p$type = 'a'
-  expect_error(LassoDevelopment$new(p), 'Your type must be regression or classification')
+  expect_error(LassoDevelopment$new(p), 'Your type must be regression, classification, or multiclass')
 })
 
 test_that("Error is thrown when predicted column isn't binary and type is classification", {
@@ -54,7 +52,7 @@ test_that("AUC_lmm is the same each time the test is run", {
   capture.output(lmm <- LinearMixedModelDevelopment$new(p))
   capture.output(expect_warning(lmm$run()))
 
-  expect_true(as.numeric(lmm$getAUROC()) - 0.849 < 1.0e-6)
+  expect_true(as.numeric(lmm$getAUROC()) - 0.9222222 < 1.0e-6)
 
 })
 
@@ -69,7 +67,7 @@ test_that("rmse_lmm is the same each time the test is run", {
   capture.output(lmm <- LinearMixedModelDevelopment$new(p))
   capture.output(lmm$run())
 
-  expect_true(as.numeric(lmm$getRMSE()) - 0.9330424 < 1.0e-6)
+  expect_true(as.numeric(lmm$getRMSE()) - 1.013385 < 1.0e-6)
 
 })
 
@@ -84,7 +82,7 @@ test_that("mae_lmm is the same each time the test is run", {
   capture.output(lmm <- LinearMixedModelDevelopment$new(p))
   capture.output(lmm$run())
 
-  expect_true(as.numeric(lmm$getMAE()) - 0.6494059 < 1.0e-6)
+  expect_true(as.numeric(lmm$getMAE()) - 0.71855611 < 1.0e-6)
 
 })
 
@@ -94,7 +92,6 @@ test_that("mae_lmm is the same each time the test is run", {
 test_that("AUC_lasso is the same each time the test is run", {
   df$PatientID <- NULL #<- Note this happens affects all following tests
 
-  skip_on_cran()
   p <- initializeParamsForTesting(df)
   p$df = df
   p$type = 'classification'
@@ -103,12 +100,11 @@ test_that("AUC_lasso is the same each time the test is run", {
   capture.output(grLasso <- LassoDevelopment$new(p))
   capture.output(grLasso$run())
 
-  expect_true(as.numeric(grLasso$getAUROC()) - 0.6935 < 1.0e-6)
+  expect_true(as.numeric(grLasso$getAUROC()) - 0.7353293 < 1.0e-6)
 })
 
 test_that("rmse_lasso is the same each time the test is run non-factor column", {
 
-  skip_on_cran()
   p <- initializeParamsForTesting(df)
   p$type = 'regression'
   p$predictedCol = 'A1CNBR'
@@ -116,13 +112,12 @@ test_that("rmse_lasso is the same each time the test is run non-factor column",
   capture.output(grLasso <- LassoDevelopment$new(p))
   capture.output(grLasso$run())
 
-  expect_true(as.numeric(grLasso$getRMSE()) - 1.118151 < 1.0e-6)
+  expect_true(as.numeric(grLasso$getRMSE()) - 1.14930401 < 1.0e-6)
 
 })
 
 test_that("mae_lasso is the same each time the test is run non-factor column", {
 
-  skip_on_cran()
   p <- initializeParamsForTesting(df)
   p$type = 'regression'
   p$predictedCol = 'A1CNBR'
@@ -130,7 +125,7 @@ test_that("mae_lasso is the same each time the test is run non-factor column", {
   capture.output(grLasso <- LassoDevelopment$new(p))
   capture.output(grLasso$run())
 
-  expect_true(as.numeric(grLasso$getMAE()) - 0.9480022 < 1.0e-6)
+  expect_true(as.numeric(grLasso$getMAE()) - 0.95895099 < 1.0e-6)
 
 })
 
@@ -139,7 +134,6 @@ test_that("mae_lasso is the same each time the test is run non-factor column", {
 
 test_that("AUC_rf is the same each time the test is run", {
   
-  skip_on_cran()
   p <- initializeParamsForTesting(df)
   p$type = 'classification'
   p$predictedCol = 'ThirtyDayReadmitFLG'
@@ -153,7 +147,6 @@ test_that("AUC_rf is the same each time the test is run", {
 
 test_that("rmse_rf is the same each time the test is run non-factor column", {
 
-  skip_on_cran()
   p <- initializeParamsForTesting(df)
   p$type = 'regression'
   p$predictedCol = 'A1CNBR'
@@ -167,7 +160,6 @@ test_that("rmse_rf is the same each time the test is run non-factor column", {
 
 test_that("mae_rf is the same each time the test is run non-factor column", {
 
-  skip_on_cran()
   p <- initializeParamsForTesting(df)
   p$type = 'regression'
   p$predictedCol = 'A1CNBR'
@@ -179,4 +171,21 @@ test_that("mae_rf is the same each time the test is run non-factor column", {
 
 })
 
+test_that("dev grainCol not in dev df gives proper error", {
+  
+  p$type <- "classification"
+  p$predictedCol <- "ThirtyDayReadmitFLG"
+  p$grainCol <- "Winnie the Pooh"
+  
+  expect_error(RandomForestDevelopment$new(p), "Your specified grainCol is not")
+  
+})
 
+test_that("dev predictedCol not in dev df gives proper error", {
+  
+  p$grainCol <- 'PatientEncounterID'
+  p$type <- "classification"
+  p$predictedCol <- "fleshEatingDandruff"
+  
+  expect_error(RandomForestDevelopment$new(p), "Your specified predictedCol is")
+})
