@@ -9,7 +9,7 @@ df <- read.csv(file = csvfile,
                     header = TRUE,
                     na.strings = c('NULL', 'NA', ""))
 
-
+set.seed(5)
 p <- SupervisedModelDevelopmentParams$new()
 p$df = df
 p$groupCol = 'GenderFLG'
@@ -18,16 +18,10 @@ p$predictedCol = 'ThirtyDayReadmitFLG'
 p$debug = FALSE
 p$cores = 1
 
-set.seed(5)
 riskAdjComp <- RiskAdjustedComparisons$new(p)
 capture.output(riskAdjComp$run())
 
-# test_that("Risk-adjusted comparison is as expected for group 1", {
-#   print(riskAdjComp$dfReturn[1,'comparativePerformance']) # for debugging.
-#   expect_identical(riskAdjComp$dfReturn[1,'comparativePerformance'], -5.5)
-# })
-# 
-# test_that("Risk-adjusted comparison is as expected for group 2", {
-#   print(riskAdjComp$dfReturn[2,'comparativePerformance']) # for debugging.
-#   expect_identical(riskAdjComp$dfReturn[2,'comparativePerformance'], 5.5)
-# })
+test_that("Risk-adjusted comparison runs", {
+  expect_equal(as.character(riskAdjComp$dfReturn$groupbyList[1]), 'M')
+  expect_equal(class(riskAdjComp$dfReturn$comparativePerformance), 'numeric')
+})
